package Daje::Plugin::Perl::Base::Common;
use Mojo::Base -base, -signatures;

our $VERSION = '0.01';

has 'template';
has 'json';

1;
#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Plugin::Perl::Base::Common


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


=cut

